"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var environment_1 = require("../src/util/environment");
describe('environment', function () {
    var keepEnv;
    beforeEach(function () {
        keepEnv = process.env.NODE_ENV;
    });
    afterEach(function () {
        process.env.NODE_ENV = keepEnv;
    });
    describe('isEnv', function () {
        it("should match when there's a value", function () {
            ['production', 'development', 'test'].forEach(function (env) {
                process.env.NODE_ENV = env;
                chai_1.assert.isTrue(environment_1.isEnv(env));
            });
        });
        it("should treat no proces.env.NODE_ENV as it'd be in development", function () {
            delete process.env.NODE_ENV;
            chai_1.assert.isTrue(environment_1.isEnv('development'));
        });
    });
    describe('isProduction', function () {
        it('should return true if in production', function () {
            process.env.NODE_ENV = 'production';
            chai_1.assert.isTrue(environment_1.isProduction());
        });
        it('should return false if not in production', function () {
            process.env.NODE_ENV = 'test';
            chai_1.assert.isTrue(!environment_1.isProduction());
        });
    });
    describe('isTest', function () {
        it('should return true if in test', function () {
            process.env.NODE_ENV = 'test';
            chai_1.assert.isTrue(environment_1.isTest());
        });
        it('should return true if not in test', function () {
            process.env.NODE_ENV = 'development';
            chai_1.assert.isTrue(!environment_1.isTest());
        });
    });
    describe('isDevelopment', function () {
        it('should return true if in development', function () {
            process.env.NODE_ENV = 'development';
            chai_1.assert.isTrue(environment_1.isDevelopment());
        });
        it('should return true if not in development and environment is defined', function () {
            process.env.NODE_ENV = 'test';
            chai_1.assert.isTrue(!environment_1.isDevelopment());
        });
        it('should make development as the default environment', function () {
            delete process.env.NODE_ENV;
            chai_1.assert.isTrue(environment_1.isDevelopment());
        });
    });
});
//# sourceMappingURL=environment.js.map