"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var warnOnce_1 = require("../src/util/warnOnce");
var lastWarning;
var keepEnv;
var numCalls = 0;
var oldConsoleWarn;
describe('warnOnce', function () {
    beforeEach(function () {
        keepEnv = process.env.NODE_ENV;
        numCalls = 0;
        lastWarning = null;
        oldConsoleWarn = console.warn;
        console.warn = function (msg) {
            numCalls++;
            lastWarning = msg;
        };
    });
    afterEach(function () {
        process.env.NODE_ENV = keepEnv;
        console.warn = oldConsoleWarn;
    });
    it('actually warns', function () {
        process.env.NODE_ENV = 'development';
        warnOnce_1.warnOnceInDevelopment('hi');
        chai_1.assert(lastWarning === 'hi');
        chai_1.expect(numCalls).to.equal(1);
    });
    it('does not warn twice', function () {
        process.env.NODE_ENV = 'development';
        warnOnce_1.warnOnceInDevelopment('ho');
        warnOnce_1.warnOnceInDevelopment('ho');
        chai_1.expect(lastWarning).to.equal('ho');
        chai_1.expect(numCalls).to.equal(1);
    });
    it('warns two different things once each', function () {
        process.env.NODE_ENV = 'development';
        warnOnce_1.warnOnceInDevelopment('slow');
        chai_1.expect(lastWarning).to.equal('slow');
        warnOnce_1.warnOnceInDevelopment('mo');
        chai_1.expect(lastWarning).to.equal('mo');
        chai_1.expect(numCalls).to.equal(2);
    });
    it('does not warn in production', function () {
        process.env.NODE_ENV = 'production';
        warnOnce_1.warnOnceInDevelopment('lo');
        warnOnce_1.warnOnceInDevelopment('lo');
        chai_1.expect(numCalls).to.equal(0);
    });
    it('warns many times in test', function () {
        process.env.NODE_ENV = 'test';
        warnOnce_1.warnOnceInDevelopment('yo');
        warnOnce_1.warnOnceInDevelopment('yo');
        chai_1.expect(lastWarning).to.equal('yo');
        chai_1.expect(numCalls).to.equal(2);
    });
});
//# sourceMappingURL=warnOnce.js.map